/***********************************************
 * HEADER: MENU SLIDE
 ***********************************************/

(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof gsap == 'undefined') {
		return;
	}

	let menuIsOpen = false;

	VLTJS.menuSlide = {
		config: {
			easing: 'power2.out'
		},
		init: function () {

			const $menu = $('.vlt-nav--slide'),
				$menuToggle = $('.js-slide-menu-toggle'),
				$navItem = $menu.find('ul.sf-menu > li'),
				$siteOverlay = $('.vlt-site-overlay');

			$menuToggle.on('click', function (e) {
				e.preventDefault();
				if (!menuIsOpen) {
					VLTJS.menuSlide.open_menu($menuToggle, $menu, $navItem, $siteOverlay);
				} else {
					VLTJS.menuSlide.close_menu($menuToggle, $menu, $siteOverlay);
				}
			});

			VLTJS.document.on('vlt.close-slide-menu', function () {
				if (menuIsOpen) {
					VLTJS.menuSlide.close_menu($menuToggle, $menu, $siteOverlay);
				}
			});

			VLTJS.document.keyup(function (e) {
				if (e.keyCode === 27 && menuIsOpen) {
					e.preventDefault();
					VLTJS.menuSlide.close_menu($menuToggle, $menu, $siteOverlay);
				}
			});

			$siteOverlay.on('click', function () {
				if (menuIsOpen) {
					VLTJS.menuSlide.close_menu($menuToggle, $menu, $siteOverlay);
				}
			});

		},
		open_menu: function (menuToggle, menu, navItem, siteOverlay) {

			// trigger close event
			VLTJS.document.trigger('vlt.close-search-popup');
			VLTJS.document.trigger('vlt.close-offcanvas-sidebar');

			menuIsOpen = true;
			menu.addClass('is-open');
			menuToggle.addClass('is-open');
			siteOverlay.addClass('is-open');

			gsap.fromTo(navItem, {
				autoAlpha: 0,
				y: 30
			}, {
				autoAlpha: 1,
				y: 0,
				duration: .3,
				delay: .3,
				stagger: {
					amount: .3
				}
			});

			// play audio
			if (VLT_LOCALIZE_DATAS.open_click_sound && typeof Howl !== 'undefined') {
				new Howl({
					src: [VLT_LOCALIZE_DATAS.open_click_sound],
					autoplay: true,
					loop: false,
					volume: 0.3
				});
			}

		},
		close_menu: function (menuToggle, menu, siteOverlay) {

			menuIsOpen = false;
			menu.removeClass('is-open');
			menuToggle.removeClass('is-open');
			siteOverlay.removeClass('is-open');

			// play audio
			if (typeof VLT_LOCALIZE_DATAS.close_click_sound && typeof Howl !== 'undefined') {
				new Howl({
					src: [VLT_LOCALIZE_DATAS.close_click_sound],
					autoplay: true,
					loop: false,
					volume: 0.3
				});
			}

		}
	};

	VLTJS.menuSlide.init();

})(jQuery);