/***********************************************
 * THEME: AJAX LIVE SEARCH FORM
 ***********************************************/
(function ($) {

	'use strict';

	VLTJS.ajaxSearch = {

		init: function () {

			const $form = $('.vlt-search-form--ajax'),
				ajaxURL = VLT_LOCALIZE_DATAS.admin_ajax;

			$form.each(function () {

				const $this = $(this),
					$input = $this.find('input[type="text"]'),
					$resultsArea = $this.find('.vlt-search-form__results');

				let visible = false;

				$input.on('keyup', function (e) {
					VLTJS.debounce(startSearch(e), 500);
				});

				$this.on('submit', function(e) {
					e.preventDefault();
				});

				VLTJS.document.on('click', function(e) {
					if (visible) {
						if ( ! e.target.classList[0].includes('vlt-search-form--ajax') ) {
							visible = false;
							$input.val('');
							$resultsArea.fadeOut();
							setTimeout(function() {
								$resultsArea.html('');
							}, 600);
						}
					}
				});

				function startSearch(event) {
					const $currentInput = $(event.target),
						datas = [
							$currentInput.siblings('input[name="post_type"]').val(),
							$currentInput.siblings('input[name="post_taxonomy"]').val(),
							$currentInput.siblings('input[name="post_term_id"]').val()
						];
					if ($currentInput.val().length >= 3) {
						$resultsArea.fadeIn();
						runAjaxFiltering($currentInput.val(), datas);
						visible = true;
					} else {
						$resultsArea.fadeOut();
						visible = false;
					}
				}

				function runAjaxFiltering(searchTarget, datas) {
					$.ajax({
						type: 'POST',
						url: ajaxURL,
						data: {
							action: 'ajax-search-results',
							searchType: datas[0],
							searchTaxonomy: datas[1],
							searchTermID: datas[2],
							searchTarget: searchTarget
						},
						beforeSend: function () {
							$resultsArea.html(VLT_LOCALIZE_DATAS.search_loading);
						},
						success: function (data) {
							if (data.length) {
								$resultsArea.html(data);
							} else {
								$resultsArea.html(VLT_LOCALIZE_DATAS.search_no_found);
							}
						},
						error: function (request, status, error) {},
					});
				}

			});


		}

	};

	VLTJS.ajaxSearch.init();

})(jQuery);