/***********************************************
 * THEME: CUSTOM CURSOR
 ***********************************************/
(function ($) {

	'use strict';

	if (VLTJS.isMobileDevice()) {
		return;
	}

	if (!$('.vlt-is--custom-cursor').length) {
		return;
	}

	VLTJS.customCursor = {
		init: function () {

			VLTJS.body.append('<div class="vlt-custom-cursor"><span class="circle-outer"></span><span class="circle-inner"></span></div>');

			const $customCursor = $('.vlt-custom-cursor'),
				adminbarHeight = 0,
				$circleOuter = $customCursor.find('.circle-outer'),
				$circleInner = $customCursor.find('.circle-inner'),
				startPosition = {
					x: 0,
					y: 0
				},
				endPosition = {
					x: 0,
					y: 0
				},
				delta = .25;

			if (typeof gsap != 'undefined') {
				gsap.set([$circleOuter, $circleInner], {
					xPercent: -50,
					yPercent: -50
				});

				VLTJS.document.on('mousemove', function (e) {
					const offsetTop = window.pageYOffset || document.documentElement.scrollTop;
					startPosition.x = e.pageX;
					startPosition.y = e.pageY - offsetTop - adminbarHeight;
				});

				gsap.ticker.add(function () {
					endPosition.x += (startPosition.x - endPosition.x) * delta;
					endPosition.y += (startPosition.y - endPosition.y) * delta;
					gsap.set([$circleOuter, $circleInner], {
						x: endPosition.x,
						y: endPosition.y
					})
				});

				VLTJS.document.on('mouseenter', function () {
					gsap.to([$circleOuter, $circleInner], .15, {
						opacity: 1
					});
				}).on('mouseleave', function () {
					gsap.to([$circleOuter, $circleInner], .15, {
						opacity: 0
					});
				});

				VLTJS.document.on('mouseenter', 'input, textarea, select, a, button, [role="button"]', function () {
					gsap.to($circleInner, .15, {
						scale: 0
					});
					gsap.to($circleOuter, .15, {
						scale: 2,
						backgroundColor: '#ffffff'
					});
				}).on('mouseleave blur', 'input, textarea, select, a, button, [role="button"]', function () {
					gsap.to($circleInner, .15, {
						scale: 1
					});
					gsap.to($circleOuter, .15, {
						scale: 1,
						backgroundColor: 'transparent'
					});
				});

				VLTJS.document.on('mousedown', function () {
					gsap.to($circleOuter, .15, {
						scale: 1.75
					});
					gsap.to($circleInner, .15, {
						scale: 0
					});
				}).on('mouseup', function () {
					gsap.to($circleOuter, .15, {
						scale: 1
					});
					gsap.to($circleInner, .15, {
						scale: 1
					});
				});

			}

		}
	};

	VLTJS.customCursor.init();

})(jQuery);