/***********************************************
 * THEME: OFFCANVAS SIDEBAR
 ***********************************************/
(function ($) {

	'use strict';

	let sidebarIsOpen = false;

	VLTJS.offcanvasSidebar = {
		config: {
			easing: 'power2.out'
		},
		init: function () {

			const $sidebar = $('.vlt-offcanvas-sidebar'),
				$sidebarToggle = $('.js-offcanvas-sidebar-toggle'),
				$sidebarClose = $('.js-offcanvas-sidebar-close'),
				$siteOverlay = $('.vlt-site-overlay');

			$sidebarToggle.on('click', function (e) {
				e.preventDefault();
				if (!sidebarIsOpen) {
					VLTJS.offcanvasSidebar.open_sidebar($sidebar, $siteOverlay, $sidebarToggle);
				} else {
					VLTJS.offcanvasSidebar.close_sidebar($sidebar, $siteOverlay, $sidebarToggle);
				}
			});

			$sidebarClose.on('click', function (e) {
				e.preventDefault();
				if (sidebarIsOpen) {
					VLTJS.offcanvasSidebar.close_sidebar($sidebar, $siteOverlay, $sidebarToggle);
				}
			});

			$siteOverlay.on('click', function (e) {
				e.preventDefault();
				if (sidebarIsOpen) {
					VLTJS.offcanvasSidebar.close_sidebar($sidebar, $siteOverlay, $sidebarToggle);
				}
			});

			VLTJS.throttleScroll(function(type, scroll) {
				const start = 300;
				if (scroll > start) {
					if (sidebarIsOpen) {
						VLTJS.offcanvasSidebar.close_sidebar($sidebar, $siteOverlay, $sidebarToggle);
					}
				}
			});

			VLTJS.document.on('vlt.close-offcanvas-sidebar', function () {
				if (sidebarIsOpen) {
					VLTJS.offcanvasSidebar.close_sidebar($sidebar, $siteOverlay, $sidebarToggle);
				}
			});

			VLTJS.document.on('keyup', function (e) {
				if (e.keyCode === 27 && sidebarIsOpen) {
					e.preventDefault();
					VLTJS.offcanvasSidebar.close_sidebar($sidebar, $siteOverlay, $sidebarToggle);
				}
			});

		},
		open_sidebar: function (sidebar, siteOverlay, sidebarToggle) {
			VLTJS.document.trigger('vlt.close-search-popup');
			VLTJS.document.trigger('vlt.close-fullscreen-menu');
			VLTJS.document.trigger('vlt.close-mobile-menu');
			VLTJS.document.trigger('vlt.close-offcanvas-menu');
			VLTJS.document.trigger('vlt.close-slide-menu');

			sidebarIsOpen = true;
			sidebar.addClass('is-open');
			sidebarToggle.addClass('is-open');
			siteOverlay.addClass('is-open');
			if (VLT_LOCALIZE_DATAS.open_click_sound && typeof Howl !== 'undefined') {
				new Howl({
					src: [VLT_LOCALIZE_DATAS.open_click_sound],
					autoplay: true,
					loop: false,
					volume: 0.3
				});
			}
		},
		close_sidebar: function (sidebar, siteOverlay, sidebarToggle) {
			sidebarIsOpen = false;
			sidebar.removeClass('is-open');
			sidebarToggle.removeClass('is-open');
			siteOverlay.removeClass('is-open');
			if (typeof VLT_LOCALIZE_DATAS.close_click_sound && typeof Howl !== 'undefined') {
				new Howl({
					src: [VLT_LOCALIZE_DATAS.close_click_sound],
					autoplay: true,
					loop: false,
					volume: 0.3
				});
			}
		}
	}

	VLTJS.offcanvasSidebar.init();

})(jQuery);