/***********************************************
 * SHOWCASE: STYLE 10
 ***********************************************/
(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof Swiper === 'undefined') {
		return;
	}

	const showcaseStyle10 = function ($scope, $) {

		const $showcase = $scope.find('.vlt-showcase--style-10'),
			dataAnchor = $showcase.data('navigation-anchor'),
			dataGap = $showcase.data('gap') || 0;

		const swiper = new Swiper($showcase, {
			init: false,
			lazy: true,
			loop: false,
			spaceBetween: dataGap,
			mousewheel: {
				releaseOnEdges: true,
			},
			slidesPerView: 1,
			speed: 1000,
			grabCursor: true,
			touchReleaseOnEdges: true,
			breakpoints: {
				// when window width is >= 576px
				576: {
					slidesPerView: 1
				},
				// when window width is >= 768px
				768: {
					slidesPerView: 2
				},
				// when window width is >= 992px
				992: {
					slidesPerView: 3
				}
			},
			navigation: {
				nextEl: $(dataAnchor).find('.vlt-swiper-button--next'),
				prevEl: $(dataAnchor).find('.vlt-swiper-button--prev'),
			},
			pagination: {
				el: $(dataAnchor).find('.vlt-swiper-pagination'),
				clickable: false,
				type: 'fraction',
				renderFraction: function (currentClass, totalClass) {
					return '<span class="' + currentClass + '"></span>' +
						'<span class="sep">/</span>' +
						'<span class="' + totalClass + '"></span>';
				}
			},
		});

		VLTJS.document.on('keyup', function (e) {
			if (e.keyCode == 37) {
				// left
				swiper.slidePrev();
			} else if (e.keyCode == 39) {
				// right
				swiper.slideNext();
			}
		});

		swiper.on('init slideChange', function () {

			const $progress = $(dataAnchor).find('.vlt-swiper-progress'),
				current = swiper.realIndex,
				total = $showcase.find('.swiper-slide').not('.swiper-slide-duplicate').length,
				scale = (current + 1) / total;

			if ($progress.data('direction') == 'vertical') {
				$progress.find('.current').text(VLTJS.addLedingZero(current + 1));
				$progress.find('.total').text(VLTJS.addLedingZero(total));
			} else {
				$progress.find('.current').text(current + 1);
				$progress.find('.total').text(total);
			}

			if ($progress.length && $progress.find('.bar > span').length) {
				$progress.find('.bar > span')[0].style.setProperty('--scaleX', scale);
				$progress.find('.bar > span')[0].style.setProperty('--speed', swiper.params.speed + 'ms');
			}

		});

		swiper.init();

	};

	VLTJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/vlt-showcase-10.default',
			showcaseStyle10
		);
	});

})(jQuery);