/***********************************************
 * SHOWCASE: STYLE 13
 ***********************************************/
(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof Swiper === 'undefined') {
		return;
	}

	const showcaseStyle13 = function ($scope, $) {

		const $showcase = $scope.find('.vlt-showcase--style-13'),
			$links = $showcase.find('.vlt-showcase-links'),
			$images = $showcase.find('.vlt-showcase-images'),
			dataAnchor = $showcase.data('navigation-anchor');

		const swiperImages = new Swiper($images, {
			init: false,
			loop: false,
			lazy: true,
			spaceBetween: 0,
			slidesPerView: 1,
			speed: 1000,
			mousewheel: true
		});

		const swiperLinks = new Swiper($links, {
			init: false,
			loop: false,
			spaceBetween: 0,
			slidesPerView: 'auto',
			speed: 1000,
			mousewheel: true,
			centeredSlides: true,
			navigation: {
				nextEl: $(dataAnchor).find('.vlt-swiper-button--next'),
				prevEl: $(dataAnchor).find('.vlt-swiper-button--prev'),
			},
			pagination: {
				el: $(dataAnchor).find('.vlt-swiper-pagination'),
				clickable: false,
				type: 'fraction',
				renderFraction: function (currentClass, totalClass) {
					return '<span class="' + currentClass + '"></span>' +
						'<span class="sep">/</span>' +
						'<span class="' + totalClass + '"></span>';
				}
			},
		});

		swiperImages.controller.control = swiperLinks;
		swiperLinks.controller.control = swiperImages;

		VLTJS.document.on('keyup', function (e) {
			if (e.keyCode == 37) {
				// left
				swiperImages.slidePrev();
			} else if (e.keyCode == 39) {
				// right
				swiperImages.slideNext();
			}
		});

		swiperImages.on('init slideChange', function () {

			const $progress = $(dataAnchor).find('.vlt-swiper-progress'),
				current = swiperImages.realIndex,
				total = $images.find('.swiper-slide').not('.swiper-slide-duplicate').length,
				scale = (current + 1) / total;

			if ($progress.data('direction') == 'vertical') {
				$progress.find('.current').text(VLTJS.addLedingZero(current + 1));
				$progress.find('.total').text(VLTJS.addLedingZero(total));
			} else {
				$progress.find('.current').text(current + 1);
				$progress.find('.total').text(total);
			}

			if ($progress.length && $progress.find('.bar > span').length) {
				$progress.find('.bar > span')[0].style.setProperty('--scaleX', scale);
				$progress.find('.bar > span')[0].style.setProperty('--speed', swiperImages.params.speed + 'ms');
			}

		});

		swiperImages.init();
		swiperLinks.init();

	};

	VLTJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/vlt-showcase-13.default',
			showcaseStyle13
		);
	});

})(jQuery);