<?php

/**
 * @author: VLThemes
 * @version: 1.0.8
 */

/**
 * Register sidebars
 */
if ( ! function_exists( 'archee_register_sidebar' ) ) {
	function archee_register_sidebar() {

		register_sidebar( array(
			'name' => esc_html__( 'Blog Sidebar', 'archee' ),
			'id' => 'blog_sidebar',
			'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h5 class="vlt-widget__title">',
			'after_title' => '</h5>'
		) );

		if ( class_exists( 'VLThemesHelperPlugin' ) ) {

			register_sidebar( array(
				'name' => esc_html__( 'Fullscreen Menu Sidebar', 'archee' ),
				'id' => 'fullscreen_menu_sidebar',
				'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h5 class="vlt-widget__title">',
				'after_title' => '</h5>'
			) );

			register_sidebar( array(
				'name' => esc_html__( 'Offcanvas Sidebar', 'archee' ),
				'id' => 'offcanvas_sidebar',
				'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h5 class="vlt-widget__title">',
				'after_title' => '</h5>'
			) );

		}

		// shop sidebar
		if ( ARCHEE_WOOCOMMERCE ) {
			register_sidebar( array(
				'name' => esc_html__( 'Shop Sidebar', 'archee' ),
				'id' => 'shop_sidebar',
				'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h5 class="vlt-widget__title">',
				'after_title' => '</h5>'
			) );
		}

		if ( ARCHEE_DOCS ) {
			register_sidebar( array(
				'name' => esc_html__( 'Docs Sidebar', 'archee' ),
				'id' => 'docs_sidebar',
				'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
				'after_widget' => '</div>',
				'before_title' => '<h5 class="vlt-widget__title">',
				'after_title' => '</h5>'
			) );
		}

		// custom sidebars
		if ( archee_get_theme_mod( 'custom_sidebars' ) ) {
			foreach ( archee_get_theme_mod( 'custom_sidebars' ) as $sidebar ) {
				if ( ! empty( $sidebar[ 'sidebar_title' ] && ! empty( $sidebar[ 'sidebar_description' ] ) ) ) {
					register_sidebar( array(
						'name' => esc_html( $sidebar[ 'sidebar_title' ] ),
						'id' => strtolower( trim( preg_replace( '/[^A-Za-z0-9-]+/', '_', $sidebar[ 'sidebar_title' ] ) ) ),
						'description' => esc_html( $sidebar[ 'sidebar_description' ] ),
						'before_widget' => '<div id="%1$s" class="vlt-widget %2$s">',
						'after_widget' => '</div>',
						'before_title' => '<h5 class="vlt-widget__title">',
						'after_title' => '</h5>'
					) );
				}
			}
		}

	}
}
add_action( 'widgets_init', 'archee_register_sidebar' );

/**
 * Body open
 */
if ( ! function_exists( 'archee_wp_body_open' ) ) {
	function archee_wp_body_open() {

		$acf_back_to_top = archee_get_theme_mod( 'page_custom_back_to_top', true );
		if ( archee_get_theme_mod( 'back_to_top', $acf_back_to_top ) == 'show' ) {
			echo '<a href="#top" class="vlt-site-back-to-top">
				<i class="fa-regular fa-fw fa-angle-up"></i>
				<svg width="100%" height="100%" viewBox="-1 -1 102 102">
					<path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
				</svg>
			</a>';
		}

		$acf_page_custom_site_protection = archee_get_theme_mod( 'page_custom_site_protection', true );
		if ( archee_get_theme_mod( 'site_protection', $acf_page_custom_site_protection ) == 'show' && ! current_user_can( 'administrator' ) ) :
			echo '<div class="vlt-site-protection"><div>';
			echo wp_kses( archee_get_theme_mod( 'site_protection_content' ), 'archee_site_protection' );
			echo '</div></div>';
		endif;

		$acf_page_fixed_socials = archee_get_theme_mod( 'page_custom_fixed_socials', true );
		if ( archee_get_theme_mod( 'fixed_socials', $acf_page_fixed_socials ) == 'show' && archee_get_theme_mod( 'fixed_social_list' ) ) {
			echo '<div class="vlt-fixed-socials">';
			foreach ( archee_get_theme_mod( 'fixed_social_list' ) as $socialItem ) {
				if ( $socialItem[ 'social_icon' ] ) {
					echo '<a href="' . esc_url( $socialItem[ 'social_url' ] ) . '" target="_blank"><i class="' . archee_sanitize_class( $socialItem[ 'social_icon' ] ) . '"></i><span data-text="' . archee_get_social_icons()[ $socialItem[ 'social_icon' ] ] . '"></span></a>';
				}
			}
			echo '</div>';
		}

		$acf_page_night_mode_toggle_button = archee_get_theme_mod( 'page_custom_night_mode_toggle_button', true );
		if ( archee_get_theme_mod( 'night_mode_toggle_button', $acf_page_night_mode_toggle_button ) == 'show' ) {
			echo '<div class="vlt-night-mode-switcher js-night-mode-trigger">';
				echo '<div class="vlt-night-mode-switcher__toggle"></div>';
				echo '<div class="vlt-night-mode-switcher__states">';
					echo '<span class="day">' . esc_html__( 'Light', 'archee' ) . '<i class="fa-regular fa-fw fa-brightness"></i></span>';
					echo '<span class="night">' . esc_html__( 'Dark', 'archee' ) . '<i class="fa-solid fa-fw fa-moon"></i></span>';
				echo '</div>';
			echo '</div>';
		}

	}
}
add_action( 'wp_body_open', 'archee_wp_body_open' );

/**
 * Fake container
 */
if ( ! function_exists( 'archee_fake_container' ) ) {
	function archee_fake_container() {
		echo '<div class="container vlt-fake-container"></div>';
	}
}
add_action( 'wp_body_open', 'archee_fake_container' );

/**
 * Before site wrapper action
 */
if ( ! function_exists( 'archee_before_site' ) ) {
	function archee_before_site() {

		$class = 'vlt-site-wrapper';

		echo '<div class="' . archee_sanitize_class( $class ) . '">';

	}
}
add_action( 'archee/before_site', 'archee_before_site' );

/**
 * After site wrapper action
 */
if ( ! function_exists( 'archee_after_site' ) ) {
	function archee_after_site() {
		echo '</div>';
	}
}
add_action( 'archee/after_site', 'archee_after_site' );

/**
 * Change admin logo
 */
if ( ! function_exists( 'archee_change_admin_logo' ) ) {
	function archee_change_admin_logo() {
		if ( ! archee_get_theme_mod( 'login_logo_image' ) ) {
			return;
		}
		$image_url = archee_get_theme_mod( 'login_logo_image' );
		$image_w = archee_get_theme_mod( 'login_logo_image_width' );
		$image_h = archee_get_theme_mod( 'login_logo_image_height' );
		echo '<style type="text/css">
			h1 a {
				background: transparent url(' . esc_url( $image_url ) . ') 50% 50% no-repeat !important;
				width:' . esc_attr( $image_w ) . '!important;
				height:' . esc_attr( $image_h ) . '!important;
				background-size: cover !important;
			}
		</style>';
	}
}
add_action( 'login_head', 'archee_change_admin_logo' );

/**
 * Prints Tracking code
 */
if ( ! function_exists( 'archee_print_tracking_code' ) ) {
	function archee_print_tracking_code() {
		$tracking_code = archee_get_theme_mod( 'tracking_code' );
		if ( ! empty( $tracking_code ) ) {
			echo '' . $tracking_code;
		}
	}
}
add_action( 'wp_head', 'archee_print_tracking_code' );

/**
 * Add theme borders
 */
if ( ! function_exists( 'archee_add_theme_borders' ) ) {
	function archee_add_theme_borders() {

		$acf_theme_borders = archee_get_theme_mod( 'page_custom_theme_border', true );
		if ( archee_get_theme_mod( 'theme_border', $acf_theme_borders ) == 'enable' ) {

			echo '<div class="vlt-theme-borders">';
				echo '<div class="vlt-theme-borders__top vlt-theme-borders__top--shadow"></div>';
				echo '<div class="vlt-theme-borders__right vlt-theme-borders__right--shadow"></div>';
				echo '<div class="vlt-theme-borders__bottom vlt-theme-borders__bottom--shadow"></div>';
				echo '<div class="vlt-theme-borders__left vlt-theme-borders__left--shadow"></div>';

				echo '<div class="vlt-theme-borders__top"></div>';
				echo '<div class="vlt-theme-borders__right"></div>';
				echo '<div class="vlt-theme-borders__bottom"></div>';
				echo '<div class="vlt-theme-borders__left"></div>';
			echo '</div>';

		}

	}
}
add_action( 'wp_body_open', 'archee_add_theme_borders' );

/**
 * Get AJAX search results
 */
if ( ! function_exists( 'archee_get_ajax_search_results' ) ) {
	function archee_get_ajax_search_results() {

		$args = array(
			's' => $_POST[ 'searchTarget' ],
			'posts_per_page' => -1
		);

		if ( isset( $_POST[ 'searchType' ] ) ) {
			$args[ 'post_type' ] = $_POST[ 'searchType' ];
		}

		if ( isset( $_POST[ 'searchTaxonomy' ] ) && isset( $_POST[ 'searchTermID' ] ) ) {
			$args[ 'tax_query' ] = [
				[
					'taxonomy' => $_POST[ 'searchTaxonomy' ],
					'field' => 'term_id',
					'terms' => $_POST[ 'searchTermID' ]
				]
			];
		}

		$new_query = new WP_Query( $args );

		if ( $new_query->have_posts() ) :
			echo '<ul>';
			while ( $new_query->have_posts() ) : $new_query->the_post();
				$post_type = get_post_type_object( get_post_type() );
				echo '<li class="vlt-search-result vlt-search-result--' . $post_type->name . '">';
					if ( has_post_thumbnail() ) {
						echo '<span class="vlt-search-result__thumbnail">';
						the_post_thumbnail( apply_filters( 'archee/ajax-search-results-image-size', 'thumbnail' ), array( 'loading' => 'lazy' ) );
						echo '</span>';
					}
					echo '<a href="' . get_permalink() .'" class="vlt-search-result__title">' . get_the_title() . '</a>';
					//echo '<span class="badge">' . esc_html( $post_type->labels->singular_name ) . '</span>';
				echo '</li>';
			endwhile;
			echo '</ul>';
		endif;
		wp_reset_postdata();

		wp_die();
	}
}
add_action( 'wp_ajax_ajax-search-results', 'archee_get_ajax_search_results' );
add_action( 'wp_ajax_nopriv_ajax-search-results', 'archee_get_ajax_search_results' );

/**
 * Post review average
 */
if ( ! function_exists( 'archee_save_post_review' ) ) {
	function archee_save_post_review() {
		global $post;
		add_post_meta( $post->ID, 'review_average_value', false );
		if ( class_exists( 'acf' ) && have_rows( 'single_post_criteria' ) ) :
			$values = [];
			$average_value = 0;
			while ( have_rows( 'single_post_criteria' ) ) : the_row();
				$values[] = get_sub_field( 'criteria_value' );
				$average_value = array_sum( $values ) / count( $values );
			endwhile;
			update_post_meta( $post->ID, 'review_average_value', round( $average_value, 1 ) );
		else:
			delete_post_meta( $post->ID, 'review_average_value' );
		endif;
	}
}
add_action( 'save_post', 'archee_save_post_review' );