<?php

/**
 * @author: VLThemes
 * @version: 1.0.8
 */

/**
 * Upload SVG for Elementor
 */
if ( ! function_exists( 'archee_unfiltered_files_upload' ) ) {
	function archee_unfiltered_files_upload() {

		// if exists, assign to $cpt_support var
		$cpt_support = get_option( 'elementor_unfiltered_files_upload' );

		// check if option DOESN'T exist in db
		if ( ! $cpt_support ) {
			$cpt_support = '1'; //create string value default to enable upload svg
			update_option( 'elementor_unfiltered_files_upload', $cpt_support ); //write it to the database
		}
	}
}
add_action( 'elementor/init', 'archee_unfiltered_files_upload' );

/**
 * Archee Widgets Priority
 */
if ( ! class_exists( 'ElementorPro\Plugin' ) ) {
	add_filter( 'elementor/editor/localize_settings', function( $settings ) {
		if ( ! empty( $settings[ 'promotionWidgets' ] ) ) {
			$settings[ 'promotionWidgets' ] = [];
		}
		return $settings;
	}, 20 );
}

/**
 * Add Navbar Offset
 */
add_action( 'elementor/element/section/section_typo/after_section_end', function( $section, $args ) {

	$section->start_controls_section(
		'section_navbar_offset', [
			'label' => esc_html__( 'Navbar Offset', 'archee' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

	$section->add_control(
		'navbar_offset', [
			'label' => esc_html__( 'Navbar Offset', 'archee' ),
			'type' => Elementor\Controls_Manager::SWITCHER,
			'return_value' => 'has-navbar-offset',
			'prefix_class' => ''
		]
	);

	$section->add_control(
		'navbar_offset_padding', [
			'label' => esc_html__( 'Navbar Offset (With Padding)', 'archee' ),
			'type' => Elementor\Controls_Manager::SWITCHER,
			'return_value' => 'has-navbar-offset-padding',
			'prefix_class' => ''
		]
	);

	$section->end_controls_section();

}, 10, 2 );

/**
 * Add Vertical Lines
 */
add_action( 'elementor/element/section/section_typo/after_section_end', function( $section, $args ) {

	$section->start_controls_section(
		'section_vertical_lines', [
			'label' => esc_html__( 'Vertical Lines', 'archee' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

	$section->add_control(
		'vertical_lines_class', [
			'label' => esc_html__( 'Vertical Lines', 'archee' ),
			'type' => Elementor\Controls_Manager::SWITCHER,
			'return_value' => 'has-vertical-lines',
			'prefix_class' => ''
		]
	);

	$section->add_control(
		'lines_z_index', [
			'label' => esc_html__( 'Z-Index', 'archee' ),
			'type' => Elementor\Controls_Manager::NUMBER,
			'min' => -1,
			'default' => -1,
			'selectors' => [
				'{{WRAPPER}} .vlt-vertical-lines' => 'z-index: {{VALUE}};'
			],
			'condition' => [
				'vertical_lines_class' => 'has-vertical-lines'
			]
		]
	);

	$section->add_control(
		'lines_color', [
			'label' => esc_html__( 'Color', 'archee' ),
			'type' => Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .vlt-vertical-lines' => '--vlt-color: {{VALUE}};'
			],
			'condition' => [
				'vertical_lines_class' => 'has-vertical-lines'
			],
		]
	);

	$section->end_controls_section();

}, 10, 2 );

/**
 * Add Options
 */
add_action( 'elementor/element/column/section_style/after_section_end', function( $section, $args ) {

	$section->start_controls_section(
		'section_jarallax', [
			'label' => esc_html__( 'Jarallax', 'archee' ),
			'tab' => \Elementor\Controls_Manager::TAB_STYLE,
		]
	);

	$section->add_control(
		'jarallax', [
			'label' => esc_html__( 'Jarallax', 'archee' ),
			'type' => Elementor\Controls_Manager::SWITCHER,
			'return_value' => 'jarallax',
			'prefix_class' => ''
		]
	);

	$section->add_control(
		'jarallax_speed', [
			'label' => esc_html__( 'Speed', 'archee' ),
			'type' => Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range' => [
				'px' => [
					'min' => -1,
					'max' => 2,
					'step' => 0.1
				],
			],
			'condition' => [
				'jarallax' => 'jarallax'
			]
		]
	);

	$section->add_control(
		'jarallax_image_size', [
			'label' => esc_html__( 'Image Size', 'vlthemes' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'' => esc_html__( 'Default', 'archee' ),
				'auto' => esc_html__( 'Auto', 'archee' ),
				'cover' => esc_html__( 'Cover', 'archee' ),
				'contain' => esc_html__( 'Contain', 'archee' ),
			],
			'default' => '',
			'condition' => [
				'jarallax' => 'jarallax'
			]
		]
	);

	$section->add_control(
		'jarallax_image_position', [
			'label' => esc_html__( 'Image Position', 'vlthemes' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'' => esc_html__( 'Default', 'archee' ),
				'unset' => esc_html__( 'Unset', 'archee' ),
				'center center' => esc_html__( 'Center Center', 'archee' ),
				'center left' => esc_html__( 'Center Left', 'archee' ),
				'center right' => esc_html__( 'Center Right', 'archee' ),
				'top center' => esc_html__( 'Top Center', 'archee' ),
				'top left' => esc_html__( 'Top Left', 'archee' ),
				'top right' => esc_html__( 'Top Right', 'archee' ),
				'bottom center' => esc_html__( 'Bottom Center', 'archee' ),
				'bottom left' => esc_html__( 'Bottom Left', 'archee' ),
				'bottom right' => esc_html__( 'Bottom Right', 'archee' ),
				'custom' => esc_html__( 'Custom', 'archee' ),
			],
			'default' => '',
			'condition' => [
				'jarallax' => 'jarallax'
			]
		]
	);

	$section->add_control(
		'jarallax_image_position_custom', [
			'label' => esc_html__( 'Image Position', 'archee' ),
			'type' => Elementor\Controls_Manager::TEXT,
			'condition' => [
				'jarallax_image_position' => 'custom'
			]
		]
	);

	$section->add_control(
		'jarallax_video_link', [
			'label' => esc_html__( 'Video Link', 'archee' ),
			'description' => esc_html__( 'Don\'t forget "mp4:" prefix for link if you use self-hosted video.', 'archee' ),
			'type' => Elementor\Controls_Manager::TEXT,
			'condition' => [
				'jarallax' => 'jarallax'
			]
		]
	);

	$section->end_controls_section();

}, 10, 2 );

if ( ! function_exists( 'startbox_render_jarallax' ) ) {
	function startbox_render_jarallax( $widget ) {
		$settings = $widget->get_settings_for_display();
		if ( $settings[ 'jarallax' ] == 'jarallax' ) {
			$widget->add_render_attribute( '_wrapper', 'data-jarallax-video', $settings[ 'jarallax_video_link' ] );
		}

		if ( $settings[ 'jarallax_speed' ] ) {
			$widget->add_render_attribute( '_wrapper', 'data-speed', $settings[ 'jarallax_speed' ][ 'size' ] );
		}

		if ( $settings[ 'jarallax_image_size' ] ) {
			$widget->add_render_attribute( '_wrapper', 'data-img-size', $settings[ 'jarallax_image_size' ] );
		}

		if ( $settings[ 'jarallax_image_position' ] == 'custom' ) {
			$widget->add_render_attribute( '_wrapper', 'data-img-position', $settings[ 'jarallax_image_position_custom' ] );
		} else {
			$widget->add_render_attribute( '_wrapper', 'data-img-position', $settings[ 'jarallax_image_position' ] );
		}

	}
}
add_action( 'elementor/frontend/section/before_render', 'startbox_render_jarallax', 10 );
add_action( 'elementor/frontend/column/before_render', 'startbox_render_jarallax', 10 );

add_action( 'elementor/element/after_section_end', function( $element, $section_id, $args ) {

	if ( 'section' === $element->get_name() && 'section_background' === $section_id ) {

		$element->start_controls_section(
			'section_jarallax', [
				'label' => esc_html__( 'Jarallax', 'archee' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$element->add_control(
			'jarallax', [
				'label' => esc_html__( 'Jarallax', 'archee' ),
				'type' => Elementor\Controls_Manager::SWITCHER,
				'return_value' => 'jarallax',
				'prefix_class' => ''
			]
		);

		$element->add_control(
			'jarallax_speed', [
				'label' => esc_html__( 'Speed', 'archee' ),
				'type' => Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => -1,
						'max' => 2,
						'step' => 0.1
					],
				],
				'condition' => [
					'jarallax' => 'jarallax'
				]
			]
		);

		$element->add_control(
			'jarallax_image_size', [
				'label' => esc_html__( 'Image Size', 'vlthemes' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'' => esc_html__( 'Default', 'archee' ),
					'auto' => esc_html__( 'Auto', 'archee' ),
					'cover' => esc_html__( 'Cover', 'archee' ),
					'contain' => esc_html__( 'Contain', 'archee' ),
				],
				'default' => '',
				'condition' => [
					'jarallax' => 'jarallax'
				]
			]
		);

		$element->add_control(
			'jarallax_image_position', [
				'label' => esc_html__( 'Image Position', 'vlthemes' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'' => esc_html__( 'Default', 'archee' ),
					'unset' => esc_html__( 'Unset', 'archee' ),
					'center center' => esc_html__( 'Center Center', 'archee' ),
					'center left' => esc_html__( 'Center Left', 'archee' ),
					'center right' => esc_html__( 'Center Right', 'archee' ),
					'top center' => esc_html__( 'Top Center', 'archee' ),
					'top left' => esc_html__( 'Top Left', 'archee' ),
					'top right' => esc_html__( 'Top Right', 'archee' ),
					'bottom center' => esc_html__( 'Bottom Center', 'archee' ),
					'bottom left' => esc_html__( 'Bottom Left', 'archee' ),
					'bottom right' => esc_html__( 'Bottom Right', 'archee' ),
					'custom' => esc_html__( 'Custom', 'archee' ),
				],
				'default' => '',
				'condition' => [
					'jarallax' => 'jarallax'
				]
			]
		);

		$element->add_control(
			'jarallax_image_position_custom', [
				'label' => esc_html__( 'Image Position', 'archee' ),
				'type' => Elementor\Controls_Manager::TEXT,
				'condition' => [
					'jarallax_image_position' => 'custom'
				]
			]
		);

		$element->add_control(
			'jarallax_video_link', [
				'label' => esc_html__( 'Video Link', 'archee' ),
				'description' => esc_html__( 'Don\'t forget "mp4:" prefix for link if you use self-hosted video.', 'archee' ),
				'type' => Elementor\Controls_Manager::TEXT,
				'condition' => [
					'jarallax' => 'jarallax'
				]
			]
		);

		$element->end_controls_section();

	}

	if ( 'section' === $element->get_name() && 'section_advanced' === $section_id ) {

		$element->start_controls_section(
			'section_archee', [
				'label' => esc_html__( 'Archee', 'archee' ),
				'tab' => \Elementor\Controls_Manager::TAB_ADVANCED,
			]
		);

		$element->add_control(
			'is_inner_section', [
				'label' => esc_html__( 'Is Inner Section', 'archee' ),
				'type' => Elementor\Controls_Manager::SWITCHER,
				'return_value' => 'is-inner-section',
				'prefix_class' => ''
			]
		);

		$element->end_controls_section();

	}

}, 10, 3 );

/**
 * Add AOS animations
 */
add_action( 'elementor/element/common/_section_style/after_section_end', function( $element ) {

	$element->start_controls_section(
		'aos_animation_section', [
			'tab' => \Elementor\Controls_Manager::TAB_ADVANCED,
			'label' => esc_html__( 'AOS Animation', 'archee' ),
		]
	);

	$element->add_control(
		'aos_animation_name', [
			'label' => esc_html__( 'Animation Name', 'archee' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => 'NONE',
				'custom' => 'CUSTOM',
				'fade' => 'FADE',
				'fade-up' => 'FADE-UP',
				'fade-down' => 'FADE-DOWN',
				'fade-left' => 'FADE-LEFT',
				'fade-right' => 'FADE-RIGHT',
				'fade-up-right' => 'FADE-UP-RIGHT',
				'fade-up-left' => 'FADE-UP-LEFT',
				'fade-down-right' => 'FADE-DOWN-RIGHT',
				'fade-down-left' => 'FADE-DOWN-LEFT',
				'flip-up' => 'FLIP-UP',
				'flip-down' => 'FLIP-DOWN',
				'flip-left' => 'FLIP-LEFT',
				'flip-right' => 'FLIP-RIGHT',
				'slide-up' => 'SLIDE-UP',
				'slide-down' => 'SLIDE-DOWN',
				'slide-left' => 'SLIDE-LEFT',
				'slide-right' => 'SLIDE-RIGHT',
				'zoom-in' => 'ZOOM-IN',
				'zoom-in-up' => 'ZOOM-IN-UP',
				'zoom-in-down' => 'ZOOM-IN-DOWN',
				'zoom-in-left' => 'ZOOM-IN-LEFT',
				'zoom-in-right' => 'ZOOM-IN-RIGHT',
				'zoom-out' => 'ZOOM-OUT',
				'zoom-out-up' => 'ZOOM-OUT-UP',
				'zoom-out-down' => 'ZOOM-OUT-DOWN',
				'zoom-out-left' => 'ZOOM-OUT-LEFT',
				'zoom-out-right' => 'ZOOM-OUT-RIGHT',
			],
			'default' => 'none',
			'frontend_available' => true,
			'render_type' => 'none',
		]
	);

	$element->add_control(
		'aos_animation_delay', [
			'label' => esc_html__( 'Animation Delay', 'archee' ),
			'description' => esc_html__( 'Delay before the animation starts', 'archee' ),
			'type' => \Elementor\Controls_Manager::NUMBER,
			'default' => '',
			'min' => 0,
			'step' => 50,
			'condition' => [
				'aos_animation_name!' => 'none',
			],
		]
	);

	$element->add_control(
		'aos_animation_duration', [
			'label' => esc_html__( 'Animation Duration', 'archee' ),
			'description' => esc_html__( 'Change the animation duration', 'archee' ),
			'type' => \Elementor\Controls_Manager::NUMBER,
			'default' => '',
			'min' => 0,
			'step' => 50,
			'condition' => [
				'aos_animation_name!' => 'none',
			],
			'frontend_available' => true,
			'render_type' => 'none',
		]
	);

	$element->add_control(
		'aos_animation_offset', [
			'label' => esc_html__( 'Animation Offset', 'archee' ),
			'description' => esc_html__( 'Distance to start the animation (related to the browser bottom)', 'archee' ),
			'type' => \Elementor\Controls_Manager::NUMBER,
			'default' => '',
			'min' => -500,
			'max' => 500,
			'step' => 10,
			'condition' => [
				'aos_animation_name!' => 'none',
			],
		]
	);

	$element->add_control(
		'aos_animation_once', [
			'label' => esc_html__( 'Animation Once', 'archee' ),
			'description' => esc_html__( 'Animate only once while scrolling down', 'archee' ),
			'type' => \Elementor\Controls_Manager::SWITCHER,
			'return_value' => 'yes',
			'default' => 'yes',
			'condition' => [
				'aos_animation_name!' => 'none',
			],
		]
	);

	$element->end_controls_section();

}, 10, 1 );

add_action( 'elementor/element/after_section_end', function( $element, $section_id, $args ) {

	$name = $element->get_name();

	if ( ( 'section' === $name || 'column' === $name ) && 'section_advanced' === $section_id ) {

		$element->start_controls_section(
			'aos_animation_section', [
				'tab' => \Elementor\Controls_Manager::TAB_ADVANCED,
				'label' => esc_html__( 'AOS Animation', 'archee' ),
			]
		);

		$element->add_control(
			'aos_animation_name', [
				'label' => esc_html__( 'Animation Name', 'archee' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'none' => 'NONE',
					'custom' => 'CUSTOM',
					'fade' => 'FADE',
					'fade-up' => 'FADE-UP',
					'fade-down' => 'FADE-DOWN',
					'fade-left' => 'FADE-LEFT',
					'fade-right' => 'FADE-RIGHT',
					'fade-up-right' => 'FADE-UP-RIGHT',
					'fade-up-left' => 'FADE-UP-LEFT',
					'fade-down-right' => 'FADE-DOWN-RIGHT',
					'fade-down-left' => 'FADE-DOWN-LEFT',
					'flip-up' => 'FLIP-UP',
					'flip-down' => 'FLIP-DOWN',
					'flip-left' => 'FLIP-LEFT',
					'flip-right' => 'FLIP-RIGHT',
					'slide-up' => 'SLIDE-UP',
					'slide-down' => 'SLIDE-DOWN',
					'slide-left' => 'SLIDE-LEFT',
					'slide-right' => 'SLIDE-RIGHT',
					'zoom-in' => 'ZOOM-IN',
					'zoom-in-up' => 'ZOOM-IN-UP',
					'zoom-in-down' => 'ZOOM-IN-DOWN',
					'zoom-in-left' => 'ZOOM-IN-LEFT',
					'zoom-in-right' => 'ZOOM-IN-RIGHT',
					'zoom-out' => 'ZOOM-OUT',
					'zoom-out-up' => 'ZOOM-OUT-UP',
					'zoom-out-down' => 'ZOOM-OUT-DOWN',
					'zoom-out-left' => 'ZOOM-OUT-LEFT',
					'zoom-out-right' => 'ZOOM-OUT-RIGHT',
				],
				'default' => 'none',
				'frontend_available' => true,
				'render_type' => 'none',
			]
		);

		$element->add_control(
			'aos_animation_delay', [
				'label' => esc_html__( 'Animation Delay', 'archee' ),
				'description' => esc_html__( 'Delay before the animation starts', 'archee' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => '',
				'min' => 0,
				'step' => 50,
				'condition' => [
					'aos_animation_name!' => 'none',
				],
			]
		);

		$element->add_control(
			'aos_animation_duration', [
				'label' => esc_html__( 'Animation Duration', 'archee' ),
				'description' => esc_html__( 'Change the animation duration', 'archee' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => '',
				'min' => 0,
				'step' => 50,
				'condition' => [
					'aos_animation_name!' => 'none',
				],
				'frontend_available' => true,
				'render_type' => 'none',
			]
		);

		$element->add_control(
			'aos_animation_offset', [
				'label' => esc_html__( 'Animation Offset', 'archee' ),
				'description' => esc_html__( 'Distance to start the animation (related to the browser bottom)', 'archee' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => '',
				'min' => -500,
				'max' => 500,
				'step' => 10,
				'condition' => [
					'aos_animation_name!' => 'none',
				],
			]
		);

		$element->add_control(
			'aos_animation_once', [
				'label' => esc_html__( 'Animation Once', 'archee' ),
				'description' => esc_html__( 'Animate only once while scrolling down', 'archee' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'aos_animation_name!' => 'none',
				],
			]
		);

		$element->end_controls_section();

	}

}, 10, 3 );

if ( ! function_exists( 'archee_render_aos_animation' ) ) {
	function archee_render_aos_animation( $widget ) {
		$settings = $widget->get_settings_for_display();

		if ( $settings[ 'aos_animation_name' ] !== 'none' ) {

			if ( ! empty( $settings[ 'aos_animation_name' ] ) ) {
				$widget->add_render_attribute( '_wrapper', 'data-aos', $settings[ 'aos_animation_name' ] );
			}

			if ( ! empty( $settings[ 'aos_animation_offset' ] ) ) {
				$widget->add_render_attribute( '_wrapper', 'data-aos-offset', $settings[ 'aos_animation_offset' ] );
			}

			if ( ! empty( $settings[ 'aos_animation_delay' ] ) ) {
				$widget->add_render_attribute( '_wrapper', 'data-aos-delay', $settings[ 'aos_animation_delay' ] );
			}

			if ( ! empty( $settings[ 'aos_animation_duration' ] ) ) {
				$widget->add_render_attribute( '_wrapper', 'data-aos-duration', $settings[ 'aos_animation_duration' ] );
			}

			if ( ! empty( $settings[ 'aos_animation_once' ] ) ) {
				$widget->add_render_attribute( '_wrapper', 'data-aos-once', $settings[ 'aos_animation_once' ] == 'yes' ? 'true' : 'false' );
			}

		}

	}
}

add_action( 'elementor/frontend/section/before_render', 'archee_render_aos_animation', 10 );
add_action( 'elementor/frontend/column/before_render', 'archee_render_aos_animation', 10 );
add_action( 'elementor/widget/before_render_content', 'archee_render_aos_animation', 10 );

/**
 * Include
 */
add_action( 'elementor/init', function() {
	require_once ARCHEE_REQUIRE_DIRECTORY . 'inc/elementor/column.php';
} );