<?php

/**
 * @author: VLThemes
 * @version: 1.0.8
 */

/**
 * Remove WooCommerce styles
 */
add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

/**
 * Hide tab title
 */
add_filter( 'woocommerce_product_description_heading', '__return_false' );

/**
 * Check is woocommerce page
 */
if ( ! function_exists( 'archee_is_woocommerce_page' ) ) {
	function archee_is_woocommerce_page( $page = '', $endpoint = '' ) {

		if ( ! $page ){
			return ( is_cart() || is_checkout() || is_account_page() || is_wc_endpoint_url() );
		}

		switch ( $page ) {
			case 'cart':
				return is_cart();
				break;

			case 'checkout':
				return is_checkout();
				break;

			case 'account':
				return is_account_page();
				break;

			case 'endpoint':
				if( $endpoint ) {
					return is_wc_endpoint_url( $endpoint );
				}
				return is_wc_endpoint_url();
				break;
		}

		return false;
	}
}

/**
 * Set template for woo pages
 */
add_filter( 'template_include', function( $template ) {
	if ( archee_is_woocommerce_page() ) {
		if ( false !== strpos( $template, 'template-woocommerce-page.php' ) ) {
			return $template;
		}
		$new_template = THEMEBAU_REQUIRE_DIRECTORY . 'template-default-woocommerce-page.php';
		if ( '' != $new_template ) {
			return $new_template ;
		}
	}
	return $template;
}, 12 );


/**
 * Change woo breadcrumbs
 */
if ( ! function_exists( 'archee_change_breadcrumb_delimiter' ) ) {
	function archee_change_breadcrumb_delimiter( $defaults ) {
		$defaults[ 'wrap_before' ] = '<nav class="vlt-page-title__breadcrumbs">';
		$defaults[ 'delimiter' ] = '<span class="sep"><i class="fa-regular fa-fw fa-angle-right"></i></span>';
		return $defaults;
	}
}
add_filter( 'woocommerce_breadcrumb_defaults', 'archee_change_breadcrumb_delimiter' );

/**
 * Custom product category title
 */
if ( ! function_exists( 'archee_woocommerce_template_loop_category_title' ) ) {
	function archee_woocommerce_template_loop_category_title( $category ) { ?>

		<div class="vlt-product-content">

			<h5 class="vlt-product-title">

				<?php

					/**
					* woocommerce_before_subcategory hook.
					*
					* @hooked woocommerce_template_loop_category_link_open - 10
					*/
					do_action( 'woocommerce_before_subcategory', $category );

					echo esc_html( $category->name );

					if ( $category->count > 0 ) {
						echo apply_filters( 'woocommerce_subcategory_count_html', ' <span class="count">(' . $category->count . ')</span>', $category );
					}

					/**
					* woocommerce_after_subcategory hook.
					*
					* @hooked woocommerce_template_loop_category_link_close - 10
					*/
					do_action( 'woocommerce_after_subcategory', $category );

				?>

			</h5>
			<!-- /.vlt-product-title -->

		</div>

		<?php
	}
}
remove_action( 'woocommerce_shop_loop_subcategory_title', 'woocommerce_template_loop_category_title', 10 );
add_action( 'woocommerce_shop_loop_subcategory_title', 'archee_woocommerce_template_loop_category_title', 10 );

/**
 * Custom product category thumbnail
 */
if ( ! function_exists( 'archee_woocommerce_subcategory_thumbnail' ) ) {
	function archee_woocommerce_subcategory_thumbnail( $category ) {
		$small_thumbnail_size = apply_filters( 'subcategory_archive_thumbnail_size', 'woocommerce_thumbnail' );
		$dimensions = wc_get_image_size( $small_thumbnail_size );
		$thumbnail_id = get_term_meta( $category->term_id, 'thumbnail_id', true );

		if ( $thumbnail_id ) {
			$image = wp_get_attachment_image_src( $thumbnail_id, $small_thumbnail_size );
			$image = $image[0];
			$image_srcset = function_exists( 'wp_get_attachment_image_srcset' ) ? wp_get_attachment_image_srcset( $thumbnail_id, $small_thumbnail_size ) : false;
			$image_sizes = function_exists( 'wp_get_attachment_image_sizes' ) ? wp_get_attachment_image_sizes( $thumbnail_id, $small_thumbnail_size ) : false;
		} else {
			$image = wc_placeholder_img_src();
			$image_srcset = false;
			$image_sizes = false;
		}

		if ( $image ) {
			// Prevent esc_url from breaking spaces in urls for image embeds.
			// Ref: https://core.trac.wordpress.org/ticket/23605.
			$image = str_replace( ' ', '%20', $image );

			// Add responsive image markup if available.
			echo '<div class="vlt-product-media">';

			/**
			* woocommerce_before_subcategory hook.
			*
			* @hooked woocommerce_template_loop_category_link_open - 10
			*/
			do_action( 'woocommerce_before_subcategory', $category );

			if ( $image_srcset && $image_sizes ) {
				echo '<img src="' . esc_url( $image ) . '" alt="' . esc_attr( $category->name ) . '" width="' . esc_attr( $dimensions['width'] ) . '" height="' . esc_attr( $dimensions['height'] ) . '" srcset="' . esc_attr( $image_srcset ) . '" sizes="' . esc_attr( $image_sizes ) . '" />';
			} else {
				echo '<img src="' . esc_url( $image ) . '" alt="' . esc_attr( $category->name ) . '" width="' . esc_attr( $dimensions['width'] ) . '" height="' . esc_attr( $dimensions['height'] ) . '" />';
			}

			/**
			* woocommerce_after_subcategory hook.
			*
			* @hooked woocommerce_template_loop_category_link_close - 10
			*/
			do_action( 'woocommerce_after_subcategory', $category );

			echo '</div>';
		}
	}
}
remove_action( 'woocommerce_before_subcategory_title', 'woocommerce_subcategory_thumbnail', 10 );
add_action( 'woocommerce_before_subcategory_title', 'archee_woocommerce_subcategory_thumbnail', 10 );

/**
 * Update cart via AJAX
 */
if ( ! function_exists( 'archee_update_cart_data' ) ) {
	function archee_update_cart_data( $array ) {
		$array[ '.vlt-shop-cart-icon__count' ] = '<span class="vlt-shop-cart-icon__count">' . esc_html( WC()->cart->get_cart_contents_count() ) . '</span>';
		return $array;
	}
}
add_filter( 'woocommerce_add_to_cart_fragments', 'archee_update_cart_data' );

/**
 * Add comma to tag widget
 */
if ( ! function_exists( 'archee_filter_woo_tag_cloud' ) ) {
	function archee_filter_woo_tag_cloud( $array ) {
		$array['smallest'] = .875;
		$array['largest'] = .875;
		$array['unit'] = 'rem';
		$args['orderby'] = 'count';
		$args['order'] = 'DESC';
		$array['separator']= '';
		return $array;
	}
}
add_filter ( 'woocommerce_product_tag_cloud_widget_args', 'archee_filter_woo_tag_cloud' );

/**
 * Define the woocommerce_share callback
 */
if ( ! function_exists( 'archee_action_woocommerce_share' ) ) {
	function archee_action_woocommerce_share() {
		if ( ! function_exists( 'vlthemes_get_post_share_buttons' ) ) {
			return;
		}
		echo '<div class="vlt-social-share">';
		echo vlthemes_get_post_share_buttons( get_the_ID(), 'style-2' );
		echo '</div>';
	}
}
add_action( 'woocommerce_share', 'archee_action_woocommerce_share', 10 );

/**
 * Reviews args
 */
if ( ! function_exists( 'archee_product_review_list_args' ) ) {
	function archee_product_review_list_args($args) {
		$args['style'] = 'ul';
		$args['avatar_size'] = 90;
		return $args;
	}
}
add_filter( 'woocommerce_product_review_list_args', 'archee_product_review_list_args' );

/**
* Max upsells Products
*/
if ( ! function_exists( 'archee_max_upsell_products' ) ) {
	function archee_max_upsell_products( $args ) {
		$args['posts_per_page'] = 4;
		return $args;
	}
}
add_filter( 'woocommerce_output_related_products_args', 'archee_max_upsell_products' );

/**
* Max crossells Products
*/
if ( ! function_exists( 'archee_max_crosssell_products' ) ) {
	function archee_max_crosssell_products( $total ) {
		$total = '4';
		return $total;
	}
}
add_filter( 'woocommerce_cross_sells_total', 'archee_max_crosssell_products' );

/**
* Max related Products
*/
if ( ! function_exists( 'archee_related_products_args' ) ) {
	function archee_related_products_args( $args ) {
		$args['posts_per_page'] = 4;
		return $args;
	}
}
add_filter( 'woocommerce_output_related_products_args', 'archee_related_products_args' );


/**
* Custom gallery image html
*/
if ( ! function_exists( 'archee_get_gallery_image_html' ) ) {
	function archee_get_gallery_image_html( $attachment_id, $main_image = false, $id = false, $fancybox = false ) {
		$flexslider = (bool) apply_filters( 'woocommerce_single_product_flexslider_enabled', get_theme_support( 'wc-product-gallery-slider' ) );
		$gallery_thumbnail = wc_get_image_size( 'gallery_thumbnail' );
		$thumbnail_size = apply_filters( 'woocommerce_gallery_thumbnail_size', array( $gallery_thumbnail['width'], $gallery_thumbnail['height'] ) );
		$image_size = apply_filters( 'woocommerce_gallery_image_size', $main_image ? 'woocommerce_single' : $thumbnail_size );
		$full_size = apply_filters( 'woocommerce_gallery_full_size', apply_filters( 'woocommerce_product_thumbnails_large_size', 'full' ) );
		$thumbnail_src = wp_get_attachment_image_src( $attachment_id, $thumbnail_size );
		$full_src = wp_get_attachment_image_src( $attachment_id, $full_size );
		$alt_text = trim( wp_strip_all_tags( get_post_meta( $attachment_id, '_wp_attachment_image_alt', true ) ) );
		$image = wp_get_attachment_image(
			$attachment_id,
			$image_size,
			false,
			apply_filters(
				'woocommerce_gallery_image_html_attachment_image_params',
				array(
					'title' => _wp_specialchars( get_post_field( 'post_title', $attachment_id ), ENT_QUOTES, 'UTF-8', true ),
					'data-caption' => _wp_specialchars( get_post_field( 'post_excerpt', $attachment_id ), ENT_QUOTES, 'UTF-8', true ),
					'data-src' => esc_url( $full_src[0] ),
					'data-large_image' => esc_url( $full_src[0] ),
					'data-large_image_width' => esc_attr( $full_src[1] ),
					'data-large_image_height' => esc_attr( $full_src[2] ),
					'class' => esc_attr( $main_image ? 'wp-post-image' : '' ),
				),
				$attachment_id,
				$image_size,
				$main_image
			)
		);

		if ( $fancybox ) {
			return '<div data-thumb="' . esc_url( $thumbnail_src[0] ) . '" data-thumb-alt="' . esc_attr( $alt_text ) . '" class="woocommerce-product-gallery__image"><a data-fancybox="' . $id . '" href="' . esc_url( $full_src[0] ) . '">' . $image . '</a></div>';
		} else {
			return '<div data-thumb="' . esc_url( $thumbnail_src[0] ) . '" data-thumb-alt="' . esc_attr( $alt_text ) . '" class="woocommerce-product-gallery__image">' . $image . '</div>';
		}

	}
}

/**
* Get product price
*/
if ( ! function_exists( 'archee_get_product_price' ) ) {
	function archee_get_product_price( $product ) {
		$output = '';
		if ( $product->get_price_html() ) {
			$output .= '<div class="price">';
			$output .= $product->get_price_html();
			$output .= '</div>';
		}
		return $output;
	}
}

/**
 * Custom sale flash
 */
if ( ! function_exists( 'archee_woocommerce_sale_flash' ) ) {
	function archee_woocommerce_sale_flash() {
		return '<span class="vlt-badge onsale">' . esc_html__( 'Sale', 'archee' ) . '</span>';
	}
}
add_filter( 'woocommerce_sale_flash', 'archee_woocommerce_sale_flash' );

/**
 * Add new/out of stock badge
 */
if ( ! function_exists( 'archee_add_new_badge' ) ) {
	function archee_add_new_badge() {

		global $product;
		$newness_days = 30;
		$created = strtotime( $product->get_date_created() );

		if ( ! $product->is_on_sale() ) {

			if ( ( time() - ( 60 * 60 * 24 * $newness_days ) ) < $created ) {
				echo '<span class="vlt-badge itsnew">' . esc_html__( 'New', 'archee' ) . '</span>';
			}

			if ( ! $product->is_in_stock() ) {
				echo '<span class="vlt-badge outofstock">' . esc_html__( 'Out of stock', 'archee' ) . '</span>';
			}

		}

	}
}
add_action( 'archee_woocommerce_before_shop_loop_item_title', 'archee_add_new_badge', 3 );