<?php

/**
 * @author: VLThemes
 * @version: 1.0.8
 */

$acf_navbar = archee_get_theme_mod( 'page_custom_navigation', true );

$header_class = 'vlt-header vlt-header--offcanvas';

if ( archee_get_theme_mod( 'navigation_opaque', $acf_navbar ) == 'enable' ) {
	$header_class .= apply_filters( 'vlthemes/navigation_opaque', ' vlt-header--opaque' );
}

$navbar_class = 'vlt-navbar vlt-navbar--main';

if ( archee_get_theme_mod( 'navigation_transparent', $acf_navbar ) == 'enable' ) {
	$navbar_class .= apply_filters( 'vlthemes/navigation_transparent', ' vlt-navbar--transparent' );
}

if ( archee_get_theme_mod( 'navigation_transparent_always', $acf_navbar ) == 'enable' ) {
	$navbar_class .= apply_filters( 'vlthemes/navigation_transparent_always', ' vlt-navbar--transparent-always' );
}

if ( archee_get_theme_mod( 'navigation_sticky', $acf_navbar ) == 'enable' ) {
	$navbar_class .= apply_filters( 'vlthemes/navigation_sticky', ' vlt-navbar--sticky' );

	if ( archee_get_theme_mod( 'navigation_hide_on_scroll', $acf_navbar ) == 'enable' ) {

		$navbar_class .= apply_filters( 'vlthemes/navigation_hide_on_scroll', ' vlt-navbar--hide-on-scroll' );

	}

}

if ( archee_get_theme_mod( 'navigation_white_text_on_top', $acf_navbar ) == 'enable' ) {
	$navbar_class .= apply_filters( 'vlthemes/navigation_white_text_on_top', ' vlt-navbar--white-text-on-top' );
}

?>

<div class="d-none d-<?php echo archee_nav_breakpoint(); ?>-block">

	<header class="<?php echo archee_sanitize_class( $header_class ); ?>">

		<div class="<?php echo archee_sanitize_class( $navbar_class ); ?>">

			<div class="vlt-navbar-inner">

				<a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="vlt-navbar-logo">

					<?php if ( archee_get_theme_mod( 'header_logo' ) ) : ?>

						<?php

							echo wp_get_attachment_image( archee_get_theme_mod( 'header_logo' ), 'full', false, array( 'loading' => 'lazy', 'class' => 'black' ) );

							if ( archee_get_theme_mod( 'header_logo_white' ) ) {
								echo wp_get_attachment_image( archee_get_theme_mod( 'header_logo_white' ), 'full', false, array( 'loading' => 'lazy', 'class' => 'white' ) );
							}

						?>

					<?php else: ?>

						<h2><?php bloginfo( 'name' ); ?></h2>

					<?php endif; ?>

				</a>
				<!-- .vlt-navbar-logo -->

				<div class="vlt-navbar-buttons">

					<?php

						if ( archee_get_theme_mod( 'header_search', $acf_navbar ) == 'show' ) {
							get_template_part( 'template-parts/header/partials/partial', 'header-search' );
						}

					?>

					<?php get_template_part( 'template-parts/header/partials/partial', 'buttons' ); ?>

					<a href="#" class="vlt-menu-burger js-offcanvas-menu-toggle" data-tippy-content="<?php esc_attr_e( 'Menu', 'archee' ); ?>" data-tippy-placement="bottom">
						<i class="fa-regular fa-fw fa-bars"></i>
					</a>

				</div>
				<!-- /.vlt-navbar-buttons -->

			</div>
			<!-- /.vlt-navbar-inner -->

		</div>
		<!-- /.vlt-navbar -->

	</header>
	<!-- /.vlt-header--offcanvas -->

	<nav class="vlt-nav vlt-nav--offcanvas" data-submenu-effect="style-1">

		<a href="#" class="vlt-offcanvas-menu-icon-close js-offcanvas-menu-toggle">
			<i class="fa-regular fa-fw fa-xmark"></i>
		</a>

		<div class="vlt-nav--offcanvas__background"></div>

		<div class="vlt-nav-table">

			<div class="vlt-nav-row">

				<div class="vlt-gap-80"></div>

			</div>

			<div class="vlt-nav-row vlt-nav-row--full vlt-nav-row--center">

				<div class="vlt-nav--offcanvas__navigation">

					<?php get_template_part( 'template-parts/header/partials/partial', 'primary-menu' ); ?>

				</div>

			</div>

			<div class="vlt-nav-row">

				<?php if ( archee_get_theme_mod( 'header_social_list' ) ) : ?>

					<div class="vlt-navbar-socials text-center">

						<?php

							foreach ( archee_get_theme_mod( 'header_social_list' ) as $socialItem ) :

								if ( $socialItem[ 'social_icon' ] ) {
									echo '<a class="vlt-social-icon vlt-social-icon--style-2" href="' . esc_url( $socialItem[ 'social_url' ] ) . '" target="_blank"><i class="' . archee_sanitize_class( $socialItem[ 'social_icon' ] ) . '"></i></a>';
								}

							endforeach;

						?>

					</div>

				<?php endif; ?>

			</div>

		</div>

	</nav>

</div>
<!-- ./d-none d-<?php echo archee_nav_breakpoint(); ?>-block -->