<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

// Ensure visibility.
if ( empty( $product ) || false === wc_get_loop_product_visibility( $product->get_id() ) || ! $product->is_visible() ) {
	return;
}

remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );

add_action( 'archee_woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
add_action( 'archee_woocommerce_template_loop_product_link_close', 'woocommerce_template_loop_product_link_close', 5 );
add_action( 'archee_woocommerce_template_loop_add_to_cart', 'woocommerce_template_loop_add_to_cart', 10 );

switch ( wc_get_loop_prop( 'columns' ) ) {
	case 1:
		$grid_class = 'col-12';
		break;
	case 2:
		$grid_class = 'col-sm-6';
		break;
	default:
		$grid_class = 'col-md-4 col-sm-6';
		break;
	case 4:
		$grid_class = 'col-md-3 col-sm-6';
		break;
}

echo '<div class="' . archee_sanitize_class( $grid_class ) . '">';

?>

<article <?php wc_product_class( 'vlt-product vlt-product--style-1', $product ); ?>>

	<?php if ( has_post_thumbnail() ) : ?>

		<div class="vlt-product-media">

			<div class="badges">

				<?php

					do_action( 'archee_woocommerce_before_shop_loop_item_title' );

				?>

			</div>

			<?php

				/**
				* Hook: woocommerce_before_shop_loop_item.
				*
				* @hooked woocommerce_template_loop_product_link_open - 10
				*/
				do_action( 'woocommerce_before_shop_loop_item' );

				/**
				 * Hook: woocommerce_before_shop_loop_item_title.
				 *
				 * @hooked woocommerce_show_product_loop_sale_flash - 10
				 * @hooked woocommerce_template_loop_product_thumbnail - 10
				 */
				do_action( 'woocommerce_before_shop_loop_item_title' );

				/**
				* Hook: woocommerce_before_shop_loop_item.
				*
				* @hooked woocommerce_template_loop_product_link_open - 10
				*/
				do_action( 'archee_woocommerce_template_loop_product_link_close' );

				/**
				 * Hook: woocommerce_after_shop_loop_item.
				 *
				 * @hooked woocommerce_template_loop_product_link_close - 5
				 * @hooked woocommerce_template_loop_add_to_cart - 10
				 */
				do_action( 'archee_woocommerce_template_loop_add_to_cart' );

			?>

		</div>

	<?php endif; ?>

	<div class="vlt-product-content">

		<h5 class="vlt-product-title">

			<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>

		</h5>
		<!-- /.vlt-product-title -->

		<div class="vlt-product-price">

			<?php

				/**
				* Hook: woocommerce_after_shop_loop_item_title.
				*
				* @hooked woocommerce_template_loop_rating - 5
				* @hooked woocommerce_template_loop_price - 10
				*/
				do_action( 'woocommerce_after_shop_loop_item_title' );

			?>

		</div>
		<!-- /.vlt-product-price -->

	</div>

</article>

<?php echo '</div>';